//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[Improvement](index.md)/[Improvement](-improvement.md)

# Improvement

[common]\
constructor(discard: [Tile](../../mahjongutils.models/-tile/index.md), advance: [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;, advanceNum: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) = 0)
